summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/pushbutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/pushbutton.h')
-rw-r--r--kalarm/lib/pushbutton.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kalarm/lib/pushbutton.h b/kalarm/lib/pushbutton.h
index 52c761bc..d3aee32c 100644
--- a/kalarm/lib/pushbutton.h
+++ b/kalarm/lib/pushbutton.h
@@ -41,23 +41,23 @@ class PushButton : public TQPushButton
TQ_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit PushButton(TQWidget* tqparent, const char* name = 0);
+ explicit PushButton(TQWidget* parent, const char* name = 0);
/** Constructor for a push button which displays a text.
* @param text The text to show on the button.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- PushButton(const TQString& text, TQWidget* tqparent, const char* name = 0);
+ PushButton(const TQString& text, TQWidget* parent, const char* name = 0);
/** Constructor for a push button which displays an icon and a text.
* @param icon The icon to show on the button.
* @param text The text to show on the button.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- PushButton(const TQIconSet& icon, const TQString& text, TQWidget* tqparent, const char* name = 0);
+ PushButton(const TQIconSet& icon, const TQString& text, TQWidget* parent, const char* name = 0);
/** Sets whether the push button is read-only for the user.
* @param readOnly True to set the widget read-only, false to enable its action.
*/
@@ -41,23 +41,23 @@ class PushButton : public TQPushButton
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,23 +41,23 @@ class PushButton : public TQPushButton
/** Constructor for a push button which displays a text.
* @param text The text to show on the button.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,23 +41,23 @@ class PushButton : public TQPushButton
* @param icon The icon to show on the button.
* @param text The text to show on the button.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/